"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initElements = initElements;
exports.destroyElements = destroyElements;

var _isEqual = _interopRequireDefault(require("lodash/isEqual"));

var _utilities = require("./utilities");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var startPoint;
var topLine;
var leftLine;
var rightLine;
var bottomLine;
var boundaries = [];
var lastPosition;
var DOMNode;
var refreshTimerId;

function initElements() {
  var rootElement = document.body;

  if (rootElement) {
    startPoint = document.createElement('div');
    rootElement.append(startPoint);
    topLine = document.createElement('div');
    startPoint.append(topLine);
    leftLine = document.createElement('div');
    startPoint.append(leftLine);
    rightLine = document.createElement('div');
    startPoint.append(rightLine);
    bottomLine = document.createElement('div');
    startPoint.append(bottomLine);
    boundaries = [topLine, leftLine, rightLine, bottomLine, startPoint];
    hideBoundaries();
    window.addEventListener('selectComponentWrapper', updatePosition);
    startRefreshTimer();
  }
}

function destroyElements() {
  stopRefreshTimer();
  window.removeEventListener('selectComponentWrapper', updatePosition);
  boundaries.forEach(function (item) {
    if (item) {
      item.remove();
    }
  });
  boundaries = undefined;
  DOMNode = undefined;
  lastPosition = undefined;
}

function startRefreshTimer() {
  refreshTimerId = setTimeout(function () {
    refreshPosition();
    refreshTimerId = undefined;
  }, 1000);
}

function stopRefreshTimer() {
  if (refreshTimerId) {
    clearTimeout(refreshTimerId);
    refreshTimerId = undefined;
  }
}

function updatePosition(event) {
  var detail = event.detail;
  DOMNode = detail.domNode;
  refreshPosition(false);
}

function refreshPosition() {
  var restartTimer = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

  if (DOMNode) {
    var pos = (0, _utilities.offset)(DOMNode);
    var width = pos.right - pos.left;
    var height = pos.bottom - pos.top;
    var newPos = {
      top: pos.top,
      left: pos.left,
      width: width > 0 ? width : 1,
      height: height > 0 ? height : 1
    };

    if (!lastPosition || !(0, _isEqual.default)(lastPosition, newPos)) {
      lastPosition = newPos;
      showBoundaries(newPos);
    }
  } else {
    hideBoundaries();
  }

  if (restartTimer) {
    startRefreshTimer();
  }
}

function hideBoundaries() {
  boundaries.forEach(function (item) {
    if (item) {
      item.style.display = 'none';
    }
  });
  lastPosition = null;
}

var borderStyle = '2px solid #2979FF';
var borderRadius = '2px';

function showBoundaries(position) {
  boundaries.forEach(function (item) {
    if (item) {
      item.style.display = 'block';
    }
  });

  if (startPoint) {
    startPoint.style.top = "".concat(position.top, "px");
    startPoint.style.left = "".concat(position.left, "px");
    startPoint.style.width = '1px';
    startPoint.style.height = '1px';
    startPoint.style.position = 'absolute';
    startPoint.style.display = 'block';
    startPoint.style.zIndex = 999999999;

    if (topLine) {
      topLine.style.position = 'absolute';
      topLine.style.top = '0px';
      topLine.style.left = '0px';
      topLine.style.width = "".concat(position.width - 1, "px");
      topLine.style.height = '0px';
      topLine.style.borderTopLeftRadius = borderRadius;
      topLine.style.borderTopLeftRadius = borderRadius;
      topLine.style.borderTop = borderStyle;
    }

    if (leftLine) {
      leftLine.style.position = 'absolute';
      leftLine.style.top = '0px';
      leftLine.style.left = '0px';
      leftLine.style.width = '0px';
      leftLine.style.height = "".concat(position.height - 1, "px");
      leftLine.style.borderTopLeftRadius = borderRadius;
      leftLine.style.borderBottomLeftRadius = borderRadius;
      leftLine.style.borderLeft = borderStyle;
    }

    if (rightLine) {
      rightLine.style.position = 'absolute';
      rightLine.style.right = "-".concat(position.width - 1, "px");
      rightLine.style.top = '0px';
      rightLine.style.width = '0px';
      rightLine.style.height = "".concat(position.height, "px");
      rightLine.style.borderTopRightRadius = borderRadius;
      rightLine.style.borderBottomRightRadius = borderRadius;
      rightLine.style.borderRight = borderStyle;
    }

    if (bottomLine) {
      bottomLine.style.position = 'absolute';
      bottomLine.style.bottom = "-".concat(position.height - 1, "px");
      bottomLine.style.left = '0px';
      bottomLine.style.width = "".concat(position.width - 1, "px");
      bottomLine.style.height = '0px';
      bottomLine.style.borderBottomLeftRadius = borderRadius;
      bottomLine.style.borderBottomRightRadius = borderRadius;
      bottomLine.style.borderBottom = borderStyle;
    }
  }
}